@@ -14,7 +14,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner", "2.1.99", __name__[0:-6], "cdk-gitlab-runner@2.1.99.jsii.tgz"
+    "cdk-gitlab-runner",
+    "2.1.100",
+    __name__[0:-6],
+    "cdk-gitlab-runner@2.1.100.jsii.tgz",
 )
 
 __all__ = [
